#ifndef __GPIO_H__
#define __GPIO_H__

#include "common.h"
#include <assert.h>

#define GPIO_SUCC  0
#define	GPIO_ERR   1

typedef enum
{ 
	GPIO_Control_DIG   = 0, /*!< GPIO Control Digital */
	GPIO_Control_ANA	 = 1, /*!< GPIO Control Analogy  */
}GPIOControl_TypeDef;
#define IS_GPIO_Control(Ctrl) (((Ctrl) == GPIO_Control_ANA)  || ((Ctrl) == GPIO_Control_DIG) )? 1:0

typedef enum
{ 
	GPIO_Mode_OUT  = 0, /*!< GPIO Output Mode */
	GPIO_Mode_IN	 = 1, /*!< GPIO Input Mode */
}GPIOMode_TypeDef;
#define IS_GPIO_MODE(MODE) (((MODE) == GPIO_Mode_IN)  || ((MODE) == GPIO_Mode_OUT) )? 1:0

typedef enum
{ 
	GPIO_OType_PP = 0,//普通输出
	GPIO_OType_OD = 1 //开漏输出
}GPIOOType_TypeDef;
#define IS_GPIO_OTYPE(OTYPE) (((OTYPE) == GPIO_OType_PP) || ((OTYPE) == GPIO_OType_OD))? 1:0
typedef enum
{ 
	GPIO_PuPd_NOPULL = 0x00,
	GPIO_PuPd_UP     = 0x01,
	GPIO_PuPd_DOWN   = 0x02
}GPIOPuPd_TypeDef;
#define IS_GPIO_PUPD(PUPD) (((PUPD) == GPIO_PuPd_NOPULL) || ((PUPD) == GPIO_PuPd_UP) || \
                            ((PUPD) == GPIO_PuPd_DOWN))? 1:0
typedef enum
{ 
	GPIO_Level_LOW	= 0x00,
	GPIO_Level_HIGH = 0x01,
}GPIOInit_Level;



typedef enum
{ 
	GPIO_PORTA = 0x00,
	GPIO_PORTB = 0x01,		
	GPIO_PORTC = 0x02,
	GPIO_PORTD = 0x03,
	GPIO_PORTH = 0x07,

}GPIO_Port_t;

#define IS_GPIO_ALL_PERIPH(PERIPH) (((PERIPH) == GPIO_PORTA) || \
									((PERIPH) == GPIO_PORTB) || \
									((PERIPH) == GPIO_PORTC) || \
									((PERIPH) == GPIO_PORTD)|| \
									((PERIPH) == GPIO_PORTH))? 1:0

/** 
  * @brief  GPIO Bit SET and Bit RESET enumeration 
  */ 
typedef enum
{ 
  Bit_RESET = 0,
  Bit_SET
}BitAction;
#define IS_GPIO_BIT_ACTION(ACTION) (((ACTION) == Bit_RESET) || ((ACTION) == Bit_SET))



#define GPIO_Pin_0                 ((uint16_t)0x0001)  /* Pin 0 selected */
#define GPIO_Pin_1                 ((uint16_t)0x0002)  /* Pin 1 selected */
#define GPIO_Pin_2                 ((uint16_t)0x0004)  /* Pin 2 selected */
#define GPIO_Pin_3                 ((uint16_t)0x0008)  /* Pin 3 selected */
#define GPIO_Pin_4                 ((uint16_t)0x0010)  /* Pin 4 selected */
#define GPIO_Pin_5                 ((uint16_t)0x0020)  /* Pin 5 selected */
#define GPIO_Pin_6                 ((uint16_t)0x0040)  /* Pin 6 selected */
#define GPIO_Pin_7                 ((uint16_t)0x0080)  /* Pin 7 selected */
#define GPIO_Pin_8                 ((uint16_t)0x0100)  /* Pin 8 selected */
#define GPIO_Pin_9                 ((uint16_t)0x0200)  /* Pin 9 selected */
#define GPIO_Pin_10                ((uint16_t)0x0400)  /* Pin 10 selected */
#define GPIO_Pin_11                ((uint16_t)0x0800)  /* Pin 11 selected */
#define GPIO_Pin_12                ((uint16_t)0x1000)  /* Pin 12 selected */
#define GPIO_Pin_13                ((uint16_t)0x2000)  /* Pin 13 selected */
#define GPIO_Pin_14                ((uint16_t)0x4000)  /* Pin 14 selected */
#define GPIO_Pin_15                ((uint16_t)0x8000)  /* Pin 15 selected */



#define GPIO_PIN_MASK              ((uint16_t)0xFFFF) /* PIN mask for assert test */
#define IS_GPIO_PIN(PIN)           ((PIN<=GPIO_PIN_MASK)&&(((PIN) & GPIO_PIN_MASK ) != (uint16_t)0x00)) ? 1:0

#define IS_GET_GPIO_PIN(PIN) (((PIN) == GPIO_Pin_0) || \
                              ((PIN) == GPIO_Pin_1) || \
                              ((PIN) == GPIO_Pin_2) || \
                              ((PIN) == GPIO_Pin_3) || \
                              ((PIN) == GPIO_Pin_4) || \
                              ((PIN) == GPIO_Pin_5) || \
                              ((PIN) == GPIO_Pin_6) || \
															((PIN) == GPIO_Pin_7) || \
															((PIN) == GPIO_Pin_8) || \
															((PIN) == GPIO_Pin_9) || \
															((PIN) == GPIO_Pin_10) || \
															((PIN) == GPIO_Pin_11) || \
															((PIN) == GPIO_Pin_12) || \
															((PIN) == GPIO_Pin_13) || \
															((PIN) == GPIO_Pin_14) || \
                              ((PIN) == GPIO_Pin_15))? 1:0
															

#define GPIO_PinAFConfig(PXXCFG,GROUP_AF_PIN) (PXXCFG = GROUP_AF_PIN)
typedef enum {
  PB00_CFG = 0x00,
  PH04_CFG = 0x01,
  PH03_CFG = 0x02,
  PH02_CFG = 0x03,
  PH01_CFG = 0x04,
  PC14_CFG = 0x05,
  PC15_CFG = 0x06,
  PC08_CFG = 0x07,
  PC09_CFG = 0x08,
  PC10_CFG = 0x09,
  PC11_CFG = 0x0a,
  PA00_CFG = 0x0b,
  PA01_CFG = 0x0c,
  PA02_CFG = 0x0d,
  PA03_CFG = 0x0e,
//  PD07_CFG = 0x0f,
//  PD08_CFG = 0x10,
//  PD09_CFG = 0x11,
  PD10_CFG = 0x12,
  PD11_CFG = 0x13,
  PC03_CFG = 0x20,
  PC04_CFG = 0x21,
  PC05_CFG = 0x22,
  PC06_CFG = 0x23,
  PC07_CFG = 0x24,
  PC12_CFG = 0x25,
  PC13_CFG = 0x26,
  PA04_CFG = 0x27,
  PA05_CFG = 0x28,
  PA06_CFG = 0x29,
  PA07_CFG = 0x2A,
  PA08_CFG = 0x2B,
  PA09_CFG = 0x2C,
  PA10_CFG = 0x2D,
  PD00_CFG = 0x2E,
  PD01_CFG = 0x2F,
  PD12_CFG = 0x30,
  PD13_CFG = 0x31,
  PD14_CFG = 0x32,
  PD15_CFG = 0x33,
  PB01_CFG = 0x40,
  PB02_CFG = 0x41,
  PB03_CFG = 0x42,
  PB04_CFG = 0x43,
  PB05_CFG = 0x44,
  PB06_CFG = 0x45,
//  PB07_CFG = 0x46,
//  PB08_CFG = 0x47,
  PC00_CFG = 0x48,
  PC01_CFG = 0x49,
  PC02_CFG = 0x4a,
  PA11_CFG = 0x4b,
  PA12_CFG = 0x4c,
  PA13_CFG = 0x4d,
  PA14_CFG = 0x4e,
  PD02_CFG = 0x4f,
  PD03_CFG = 0x50,
//  PD04_CFG = 0x51,
//  PD05_CFG = 0x52,
//  PD06_CFG = 0x53,
}IO_CfgType;

typedef enum {
//	GRP0	
  TI00_PCFG  = 0x00,                     /*!< (@ 0x00000980) TI10 alternate function pin configuration register         */
  TI01_PCFG  = 0x01,                     /*!< (@ 0x00000981) TI11 alternate function pin configuration register         */
  TI02_PCFG  = 0x02,                     /*!< (@ 0x00000982) TI12 alternate function pin configuration register         */
  TI03_PCFG  = 0x03,                     /*!< (@ 0x00000983) TI13 alternate function pin configuration register         */	
  RXD0_PCFG  = 0x04,                     /*!< (@ 0x00000984) RXD0 alternate function pin configuration register        */
  SCLA0_PCFG = 0x05,                     /*!< (@ 0x00000985) SCLA0 alternate function pin configuration register        */	
  SDAA0_PCFG = 0x06,                     /*!< (@ 0x00000986) SDAA0 alternate function pin configuration register        */	
//	GRP1	
  TI10_PCFG  = 0x20,                     /*!< (@ 0x000009a0) TI10 alternate function pin configuration register         */
  TI11_PCFG  = 0x21,                     /*!< (@ 0x000009a1) TI11 alternate function pin configuration register         */
  TI12_PCFG  = 0x22,                     /*!< (@ 0x000009a2) TI12 alternate function pin configuration register         */
  TI13_PCFG  = 0x23,                     /*!< (@ 0x000009a3) TI13 alternate function pin configuration register         */
  RXD1_PCFG  = 0x24,                     /*!< (@ 0x000009a4) RXD1 alternate function pin configuration register        */
  SPIHS0_SCKIPCFG = 0x25,                /*!< (@ 0x000009a5) SPIHS clock alternate function pin configuration register        */
  SPIHS0_SIPCFG   = 0x26,                /*!< (@ 0x000009a5) SPIHS sip alternate function pin configuration register        */	
  SPIHS0_MIPCFG   = 0x27,                /*!< (@ 0x000009a5) SPIHS mip alternate function pin configuration register        */	
//	GRP2	
  TI14_PCFG  = 0x40,                     /*!< (@ 0x000009c0) TI14 alternate function pin configuration register         */
  TI15_PCFG  = 0x41,                     /*!< (@ 0x000009c1) TI15 alternate function pin configuration register         */
  TI16_PCFG  = 0x42,                     /*!< (@ 0x000009c2) TI16 alternate function pin configuration register         */
  TI17_PCFG  = 0x43,                     /*!< (@ 0x000009c3) TI17 alternate function pin configuration register         */	
  RXD2_PCFG  = 0x44,                     /*!< (@ 0x000009c4) RXD2 alternate function pin configuration register        */
  SPIHS1_NSSPCFG = 0x45,                 /*!< (@ 0x000009c5) SPIHS nss alternate function pin configuration register        */
  SCLA1_PCFG = 0x46,                     /*!< (@ 0x000009c6) SCLA1 alternate function pin configuration register        */	
  SDAA1_PCFG = 0x47,                     /*!< (@ 0x000009c7) SDAA1 alternate function pin configuration register        */	
	
}PortInput_CfgType;  //this list can be referred for IO input group

typedef enum
{
	GROUP_AF_ODEFAULT = 0,	//ANIxx or GPIO

//OUTPUT
	GROUP_AF_GPIO  = 0x00,
//	GRP0
	GROUP_AF_TO00  = 0x01,
	GROUP_AF_TO01  = 0x02,
  GROUP_AF_TO02  = 0x03,
	GROUP_AF_TO03  = 0x04,
	GROUP_AF_TXD0  = 0x05,
	GROUP_AF_SDO00 = 0x05,

//	GRP1	
	GROUP_AF_TO10        = 0x01,
	GROUP_AF_TO11        = 0x02,
	GROUP_AF_TO12        = 0x03,
	GROUP_AF_TO13        = 0x04,
	GROUP_AF_TXD1        = 0x05,
	GROUP_AF_IRTXD       = 0x05,
	GROUP_AF_SDO10       = 0x05,
	GROUP_AF_SPIHS0SCLKO = 0x06,
  GROUP_AF_SPIHS0MO    = 0x07,
  GROUP_AF_SPIHS0SO    = 0x08,
	
//	GRP2	
	GROUP_AF_TO14    = 0x01,
	GROUP_AF_TO15    = 0x02,	
	GROUP_AF_TO16    = 0x03,	
	GROUP_AF_TO17    = 0x04,
	GROUP_AF_TXD2    = 0x05,
	GROUP_AF_SDO20   = 0x05,
  GROUP_AF_CLKBUZ1 = 0x06,
 
//Fixed function	
	GROUP_AF_CLKBUZ0    = 0x00,		  //PA00
	GROUP_AF_SDO01 	    = 0x00,			//PA12		
	GROUP_AF_SCLKO01    = 0x00,		  //PA14
	GROUP_AF_SCL01 	    = 0x00,			//PA14
	GROUP_AF_RTC1HZ     = 0x00,			//PB00
	GROUP_AF_SCLKO21    = 0x00,		  //PB03
	GROUP_AF_SCL21 	    = 0x00,			//PB03
	GROUP_AF_SDO21 	    = 0x00,			//PB05
	GROUP_AF_SPIHS1SCKO = 0x00,		  //PC00
	GROUP_AF_SPIHS1MO 	= 0x00,			//PC01
	GROUP_AF_SPIHS1SO 	= 0x00,			//PC02	
	GROUP_AF_SCLKO11 		= 0x00,		  //PC03
	GROUP_AF_SCL11      = 0x00,			//PC03
	GROUP_AF_SDO11      = 0x00,			//PC04
	GROUP_AF_DBWRB      = 0x00,			//PC10
	GROUP_AF_DBRDB      = 0x00,			//PC11
	GROUP_AF_USBVBUSEN  = 0x00,	  	//PD01
	GROUP_AF_USBEXICEN  = 0x00,			//PD05
	GROUP_AF_SSITXD0 		= 0x00,			//PD13
	GROUP_AF_SSILRCK0O 	= 0x00,			//PD14
	GROUP_AF_SSIFS0O 		= 0x00,			//PD14
	GROUP_AF_SSIBCK0O 	= 0x00,			//PD15
	GROUP_AF_QSPCLK 		= 0x00,			//PD02
	GROUP_AF_QSSL 			= 0x00,			//PD03
	GROUP_AF_EPWMO06    = 0x00,			//PD10
	GROUP_AF_EPWMO07    = 0x00,			//PD11
	GROUP_AF_VCOUT0			= 0x00,			//PH01
	GROUP_AF_VCOUT1			= 0x00,			//PH02
	
//INPUT
//	GRP0
  PORTINPUT_CFG_PB00 = 0x01,
  PORTINPUT_CFG_PH04 = 0x02,
  PORTINPUT_CFG_PH03 = 0x03,
  PORTINPUT_CFG_PH02 = 0x04,
  PORTINPUT_CFG_PH01 = 0x05,
  PORTINPUT_CFG_PC14 = 0x06,
  PORTINPUT_CFG_PC15 = 0x07,
  PORTINPUT_CFG_PC08 = 0x08,
  PORTINPUT_CFG_PC09 = 0x09,
  PORTINPUT_CFG_PC10 = 0x0a,
  PORTINPUT_CFG_PC11 = 0x0b,
  PORTINPUT_CFG_PA00 = 0x0c,
  PORTINPUT_CFG_PA01 = 0x0d,
  PORTINPUT_CFG_PA02 = 0x0e,
  PORTINPUT_CFG_PA03 = 0x0f,
//  PORTINPUT_CFG_PD07 = 0x10,
  PORTINPUT_CFG_PD08 = 0x11,
  PORTINPUT_CFG_PD09 = 0x12,
  PORTINPUT_CFG_PD10 = 0x13,
  PORTINPUT_CFG_PD11 = 0x14,
	
//	GRP1	
  PORTINPUT_CFG_PC03 = 0x01,
  PORTINPUT_CFG_PC04 = 0x02,
  PORTINPUT_CFG_PC05 = 0x03,
  PORTINPUT_CFG_PC06 = 0x04,
  PORTINPUT_CFG_PC07 = 0x05,
  PORTINPUT_CFG_PC12 = 0x06,
  PORTINPUT_CFG_PC13 = 0x07,
  PORTINPUT_CFG_PA04 = 0x08,
  PORTINPUT_CFG_PA05 = 0x09,
  PORTINPUT_CFG_PA06 = 0x0a,
  PORTINPUT_CFG_PA07 = 0x0b,
  PORTINPUT_CFG_PA08 = 0x0c,
  PORTINPUT_CFG_PA09 = 0x0d,
  PORTINPUT_CFG_PA10 = 0x0e,
  PORTINPUT_CFG_PD00 = 0x0f,
  PORTINPUT_CFG_PD01 = 0x10,
  PORTINPUT_CFG_PD12 = 0x11,
//  PORTINPUT_CFG_PD13 = 0x12,
//  PORTINPUT_CFG_PD14 = 0x13,
//  PORTINPUT_CFG_PD15 = 0x14,

//	GRP2	                     
  PORTINPUT_CFG_PB01 = 0x01,
  PORTINPUT_CFG_PB02 = 0x02,
  PORTINPUT_CFG_PB03 = 0x03,
  PORTINPUT_CFG_PB04 = 0x04,
  PORTINPUT_CFG_PB05 = 0x05,
  PORTINPUT_CFG_PB06 = 0x06,	
//  PORTINPUT_CFG_PB07 = 0x07,	
//  PORTINPUT_CFG_PB08 = 0x08,	
  PORTINPUT_CFG_PC00 = 0x09,	
  PORTINPUT_CFG_PC01 = 0x0a,	
  PORTINPUT_CFG_PC02 = 0x0b,	
  PORTINPUT_CFG_PA11 = 0x0c,	
  PORTINPUT_CFG_PA12 = 0x0d,	
  PORTINPUT_CFG_PA13 = 0x0e,	
  PORTINPUT_CFG_PA14 = 0x0f,	
  PORTINPUT_CFG_PD02 = 0x10,	
  PORTINPUT_CFG_PD03 = 0x11,	
//  PORTINPUT_CFG_PD04 = 0x12,	
//  PORTINPUT_CFG_PD05 = 0x13,	
//  PORTINPUT_CFG_PD06 = 0x14,	

//INTP0
	PORTINTP0_CFG_PC00 = 0x00,	
	PORTINTP0_CFG_PC01 = 0x01,	
	PORTINTP0_CFG_PC02 = 0x02,	
	PORTINTP0_CFG_PC03 = 0x03,	
	PORTINTP0_CFG_PC04 = 0x04,	
	PORTINTP0_CFG_PC05 = 0x05,	
	PORTINTP0_CFG_PC06 = 0x06,	
	PORTINTP0_CFG_PC07 = 0x07,	
	
//INTP1
	PORTINTP1_CFG_PC12 = 0x00,	
	PORTINTP1_CFG_PC13 = 0x01,	
	PORTINTP1_CFG_PC14 = 0x02,	
	PORTINTP1_CFG_PC15 = 0x03,	
	PORTINTP1_CFG_PC08 = 0x04,	
	PORTINTP1_CFG_PC09 = 0x05,	
	PORTINTP1_CFG_PC10 = 0x06,	
	PORTINTP1_CFG_PC11 = 0x07,	

//INTP2
	PORTINTP2_CFG_PA00 = 0x00,	
	PORTINTP2_CFG_PA01 = 0x01,	
	PORTINTP2_CFG_PA02 = 0x02,	
	PORTINTP2_CFG_PA03 = 0x03,	
	PORTINTP2_CFG_PA11 = 0x04,	
	PORTINTP2_CFG_PA12 = 0x05,	
	PORTINTP2_CFG_PA13 = 0x06,	
	PORTINTP2_CFG_PA14 = 0x07,	

//INTP3
	PORTINTP3_CFG_PA04 = 0x00,	
	PORTINTP3_CFG_PA05 = 0x01,	
	PORTINTP3_CFG_PA06 = 0x02,	
	PORTINTP3_CFG_PA07 = 0x03,	
	PORTINTP3_CFG_PA08 = 0x04,	
	PORTINTP3_CFG_PA09 = 0x05,	
	PORTINTP3_CFG_PA10 = 0x06,	

//INTP4
	PORTINTP4_CFG_PD00 = 0x00,	
	PORTINTP4_CFG_PD01 = 0x01,	
	PORTINTP4_CFG_PD12 = 0x02,	
	PORTINTP4_CFG_PD13 = 0x03,	
	PORTINTP4_CFG_PD14 = 0x04,	
	PORTINTP4_CFG_PD15 = 0x05,	
	PORTINTP4_CFG_PD02 = 0x06,	
	PORTINTP4_CFG_PD03 = 0x07,

//INTP5
	PORTINTP5_CFG_PD08 = 0x04,		//(SCLK)	
	PORTINTP5_CFG_PD09 = 0x05,		//(DRDYB/DOUT)	
	PORTINTP5_CFG_PD10 = 0x06,	
	PORTINTP5_CFG_PD11 = 0x07,	
	
//INTP6
	PORTINTP6_CFG_PB00 = 0x00,	
	PORTINTP6_CFG_PH04 = 0x01,	
	PORTINTP6_CFG_PH03 = 0x02,	
	PORTINTP6_CFG_PH02 = 0x03,	
	PORTINTP6_CFG_PH01 = 0x04,	
	PORTINTP6_CFG_PB01 = 0x05,	
	PORTINTP6_CFG_PB02 = 0x06,	

//INTP7
	PORTINTP7_CFG_PB03 = 0x00,	
	PORTINTP7_CFG_PB04 = 0x01,	
	PORTINTP7_CFG_PB05 = 0x02,	
	PORTINTP7_CFG_PB06 = 0x03,	
//	PORTINTP7_CFG_PB07 = 0x04,	
//	PORTINTP7_CFG_PB08 = 0x05,	

	
}GROUP_AF_t;
	
#define IS_GPIO_AF(GPIO_AF) (((GPIO_AF) == GROUP_AF_ODEFAULT  || \
						(GPIO_AF) == GROUP_AF_GPIO || (GPIO_AF) == GROUP_AF_TO00 || (GPIO_AF) == GROUP_AF_TO10 || (GPIO_AF) == GROUP_AF_TO14 || \
						(GPIO_AF) == GROUP_AF_TO01 || (GPIO_AF) == GROUP_AF_TO11 || (GPIO_AF) == GROUP_AF_TO15 || (GPIO_AF) == GROUP_AF_TO02 || (GPIO_AF) == GROUP_AF_TO12 || \
						(GPIO_AF) == GROUP_AF_TO16 || (GPIO_AF) == GROUP_AF_TO03 || (GPIO_AF) == GROUP_AF_TO13 || (GPIO_AF) == GROUP_AF_TO17 || (GPIO_AF) == GROUP_AF_SDO00 || \
						(GPIO_AF) == GROUP_AF_TXD0 || (GPIO_AF) == GROUP_AF_TXD1 || (GPIO_AF) == GROUP_AF_IRTXD|| (GPIO_AF) == GROUP_AF_SDO10 || (GPIO_AF) == GROUP_AF_TXD2 || \
						(GPIO_AF) == GROUP_AF_CLKBUZ1 || (GPIO_AF) == GROUP_AF_SPIHS0SCLKO || (GPIO_AF) == GROUP_AF_SPIHS0MO || (GPIO_AF) == GROUP_AF_SPIHS0SO || (GPIO_AF) == PORTINPUT_CFG_PB00 || \
						(GPIO_AF) == GROUP_AF_CLKBUZ0 || (GPIO_AF) == GROUP_AF_SDO01 || (GPIO_AF) == GROUP_AF_SCLKO01 || (GPIO_AF) == GROUP_AF_SCL01 || (GPIO_AF) == GROUP_AF_RTC1HZ ||\
						(GPIO_AF) == GROUP_AF_SCLKO21 || (GPIO_AF) == GROUP_AF_SCL21 || (GPIO_AF) == GROUP_AF_SDO21   || (GPIO_AF) == GROUP_AF_SPIHS1SCKO ||(GPIO_AF) == GROUP_AF_SPIHS1MO ||\
						(GPIO_AF) == GROUP_AF_SPIHS1SO ||(GPIO_AF) == GROUP_AF_SCLKO11 ||(GPIO_AF) == GROUP_AF_SCL11  || (GPIO_AF) == GROUP_AF_SDO11 || (GPIO_AF) == GROUP_AF_DBWRB  ||\
						(GPIO_AF) == GROUP_AF_DBRDB   ||(GPIO_AF) == GROUP_AF_USBVBUSEN ||(GPIO_AF) == GROUP_AF_USBEXICEN ||(GPIO_AF) == GROUP_AF_SSITXD0 ||(GPIO_AF) == GROUP_AF_SSILRCK0O ||\
						(GPIO_AF) == GROUP_AF_SSIFS0O ||(GPIO_AF) == GROUP_AF_SSIBCK0O ||(GPIO_AF) == GROUP_AF_QSPCLK ||(GPIO_AF) == GROUP_AF_QSSL ||(GPIO_AF) == GROUP_AF_EPWMO06 ||\
						(GPIO_AF) == GROUP_AF_EPWMO07 ||(GPIO_AF) == GROUP_AF_VCOUT0 || (GPIO_AF) == GROUP_AF_VCOUT1  || (GPIO_AF) == GROUP_AF_SDO20 ||\
						(GPIO_AF) == PORTINPUT_CFG_PH04 || (GPIO_AF) == PORTINPUT_CFG_PH03 || (GPIO_AF) == PORTINPUT_CFG_PH02 || (GPIO_AF) == PORTINPUT_CFG_PH01 || (GPIO_AF) == PORTINPUT_CFG_PC14 || \
						(GPIO_AF) == PORTINPUT_CFG_PC15 || (GPIO_AF) == PORTINPUT_CFG_PC08 || (GPIO_AF) == PORTINPUT_CFG_PC09 || (GPIO_AF) == PORTINPUT_CFG_PC10 || (GPIO_AF) == PORTINPUT_CFG_PC11 || \
						(GPIO_AF) == PORTINPUT_CFG_PA00 || (GPIO_AF) == PORTINPUT_CFG_PA01 || (GPIO_AF) == PORTINPUT_CFG_PA02 || (GPIO_AF) == PORTINPUT_CFG_PA03 || (GPIO_AF) == PORTINPUT_CFG_PD08 || \
						(GPIO_AF) == PORTINPUT_CFG_PD09 || (GPIO_AF) == PORTINPUT_CFG_PD10 || (GPIO_AF) == PORTINPUT_CFG_PD11 || (GPIO_AF) == PORTINPUT_CFG_PC03 || (GPIO_AF) == PORTINPUT_CFG_PC04 || \
						(GPIO_AF) == PORTINPUT_CFG_PC05 || (GPIO_AF) == PORTINPUT_CFG_PC06 || (GPIO_AF) == PORTINPUT_CFG_PC07 || (GPIO_AF) == PORTINPUT_CFG_PC12 || (GPIO_AF) == PORTINPUT_CFG_PC13 || \
						(GPIO_AF) == PORTINPUT_CFG_PA04 || (GPIO_AF) == PORTINPUT_CFG_PA05 || (GPIO_AF) == PORTINPUT_CFG_PA06 || (GPIO_AF) == PORTINPUT_CFG_PA07 || (GPIO_AF) == PORTINPUT_CFG_PA08 || \
						(GPIO_AF) == PORTINPUT_CFG_PA09 || (GPIO_AF) == PORTINPUT_CFG_PA10 || (GPIO_AF) == PORTINPUT_CFG_PD00 || (GPIO_AF) == PORTINPUT_CFG_PD01 || (GPIO_AF) == PORTINPUT_CFG_PD12 || \
						(GPIO_AF) == PORTINPUT_CFG_PB01 || (GPIO_AF) == PORTINPUT_CFG_PB02 || (GPIO_AF) == PORTINPUT_CFG_PB03 || (GPIO_AF) == PORTINPUT_CFG_PB04 || (GPIO_AF) == PORTINPUT_CFG_PB05 || \
						(GPIO_AF) == PORTINPUT_CFG_PB06 || (GPIO_AF) == PORTINPUT_CFG_PC00 || (GPIO_AF) == PORTINPUT_CFG_PC01 || (GPIO_AF) == PORTINPUT_CFG_PD02 || (GPIO_AF) == PORTINPUT_CFG_PD03 || \
						(GPIO_AF) == PORTINPUT_CFG_PC02 || (GPIO_AF) == PORTINPUT_CFG_PA11 || (GPIO_AF) == PORTINPUT_CFG_PA12 || (GPIO_AF) == PORTINPUT_CFG_PA13 || (GPIO_AF) == PORTINPUT_CFG_PA14 || \
						(GPIO_AF) == PORTINTP0_CFG_PC00 || (GPIO_AF) == PORTINTP0_CFG_PC01 || (GPIO_AF) == PORTINTP0_CFG_PC02 || (GPIO_AF) ==  PORTINTP0_CFG_PC03|| (GPIO_AF) == PORTINTP0_CFG_PC04 || \
						(GPIO_AF) == PORTINTP0_CFG_PC05 || (GPIO_AF) == PORTINTP0_CFG_PC06 || (GPIO_AF) == PORTINTP0_CFG_PC07 || (GPIO_AF) ==  PORTINTP1_CFG_PC12|| (GPIO_AF) == PORTINTP1_CFG_PC13 || \
						(GPIO_AF) == PORTINTP1_CFG_PC14 || (GPIO_AF) == PORTINTP1_CFG_PC15 || (GPIO_AF) == PORTINTP1_CFG_PC08 || (GPIO_AF) ==  PORTINTP1_CFG_PC09|| (GPIO_AF) == PORTINTP1_CFG_PC10 || \
						(GPIO_AF) == PORTINTP1_CFG_PC11 || (GPIO_AF) == PORTINTP2_CFG_PA00 || (GPIO_AF) == PORTINTP2_CFG_PA01 || (GPIO_AF) ==  PORTINTP2_CFG_PA02|| (GPIO_AF) == PORTINTP2_CFG_PA03 || \
						(GPIO_AF) == PORTINTP2_CFG_PA11 || (GPIO_AF) == PORTINTP2_CFG_PA12 || (GPIO_AF) == PORTINTP2_CFG_PA13 || (GPIO_AF) ==  PORTINTP2_CFG_PA14|| (GPIO_AF) == PORTINTP3_CFG_PA04 || \
						(GPIO_AF) == PORTINTP3_CFG_PA05 || (GPIO_AF) == PORTINTP3_CFG_PA06 || (GPIO_AF) == PORTINTP3_CFG_PA07 || (GPIO_AF) ==  PORTINTP3_CFG_PA08|| (GPIO_AF) == PORTINTP3_CFG_PA09 || \
						(GPIO_AF) == PORTINTP3_CFG_PA10 || (GPIO_AF) == PORTINTP4_CFG_PD00 || (GPIO_AF) == PORTINTP4_CFG_PD01 || (GPIO_AF) ==  PORTINTP4_CFG_PD12|| (GPIO_AF) == PORTINTP4_CFG_PD13 || \
						(GPIO_AF) == PORTINTP4_CFG_PD14 || (GPIO_AF) == PORTINTP4_CFG_PD15 || (GPIO_AF) == PORTINTP4_CFG_PD02 || (GPIO_AF) ==  PORTINTP4_CFG_PD03|| (GPIO_AF) == PORTINTP5_CFG_PD10 || \
						(GPIO_AF) == PORTINTP5_CFG_PD11 || (GPIO_AF) == PORTINTP6_CFG_PB00 || (GPIO_AF) == PORTINTP6_CFG_PH04 || (GPIO_AF) ==  PORTINTP6_CFG_PH03|| (GPIO_AF) == PORTINTP6_CFG_PH02 || \
						(GPIO_AF) == PORTINTP6_CFG_PH01 || (GPIO_AF) == PORTINTP6_CFG_PB01 || (GPIO_AF) == PORTINTP6_CFG_PB02 || (GPIO_AF) ==  PORTINTP7_CFG_PB03|| (GPIO_AF) == PORTINTP7_CFG_PB04 || \
						(GPIO_AF) == PORTINTP7_CFG_PB05 || (GPIO_AF) == PORTINTP7_CFG_PB06 || (GPIO_AF) == PORTINTP5_CFG_PD08 || (GPIO_AF) == PORTINTP5_CFG_PD09/*|| (GPIO_AF) == PORTINTP7_CFG_PB07 || (GPIO_AF) ==  PORTINTP7_CFG_PB08*/ \
						)? 1:0)




typedef enum
{
	GPIO_PIN_START = 0x00, 
	GPIO_PA00 = 0x01,
	GPIO_PA01 = 0x02,
	GPIO_PA02 = 0x03,
	GPIO_PA03 = 0x04,
	GPIO_PA04 = 0x05,
	GPIO_PA05 = 0x06,
	GPIO_PA06 = 0x07,
	GPIO_PA07 = 0x08,
	GPIO_PA08 = 0x09,
	GPIO_PA09 = 0x0A,
	GPIO_PA10 = 0x0B,
	GPIO_PA11 = 0x0C,
	GPIO_PA12 = 0x0D,
	GPIO_PA13 = 0x0E,
	GPIO_PA14 = 0x0F,
	GPIO_PA15 = 0x10,
	GPIO_PB00 = 0x11,
	GPIO_PB01 = 0x12,
	GPIO_PB02 = 0x13,
	GPIO_PB03 = 0x14,
	GPIO_PB04 = 0x15,
	GPIO_PB05 = 0x16,
	GPIO_PB06 = 0x17,
//	GPIO_PB07 = 0x18,
//	GPIO_PB08 = 0x19,
//	GPIO_PB09 = 0x1A,
	GPIO_PB10 = 0x1B,
	GPIO_PB11 = 0x1C,
	GPIO_PB12 = 0x1D,
	GPIO_PB13 = 0x1E,
	GPIO_PB14 = 0x1F,
	GPIO_PB15 = 0x20,
	GPIO_PC00 = 0x21,
	GPIO_PC01 = 0x22,
	GPIO_PC02 = 0x23,
	GPIO_PC03 = 0x24,
	GPIO_PC04 = 0x25,
	GPIO_PC05 = 0x26,
	GPIO_PC06 = 0x27,
	GPIO_PC07 = 0x28,
	GPIO_PC08 = 0x29,
	GPIO_PC09 = 0x2A,
	GPIO_PC10 = 0x2B,
	GPIO_PC11 = 0x2C,
	GPIO_PC12 = 0x2D,
	GPIO_PC13 = 0x2E,	
	GPIO_PC14 = 0x2F,	
	GPIO_PC15 = 0x30,	
	GPIO_PD00 = 0x31,	
	GPIO_PD01 = 0x32,		
	GPIO_PD02 = 0x33,		
	GPIO_PD03 = 0x34,		
//	GPIO_PD04 = 0x35,		
//	GPIO_PD05 = 0x36,		
//	GPIO_PD06 = 0x37,		
//	GPIO_PD07 = 0x38,		
//	GPIO_PD08 = 0x39,
//	GPIO_PD09 = 0x3A,
	GPIO_PD10 = 0x3B,
	GPIO_PD11 = 0x3C,
	GPIO_PD12 = 0x3D,
	GPIO_PD13 = 0x3E,
	GPIO_PD14 = 0x3F,
	GPIO_PD15 = 0x40,
	GPIO_PH01 = 0x41,		
	GPIO_PH02 = 0x42,			
	GPIO_PH03 = 0x43,			
	GPIO_PH04 = 0x44,			
	GPIO_PIN_END = 0x45,
}GPIO_Source_t;

 

typedef struct 
{
	uint16_t GPIO_Pin;						/*!< Specifies the GPIO pins to be configured.
										  This parameter can be any value of @ref GPIO_pins_define */
	GPIOMode_TypeDef GPIO_Mode;	  /*!< Specifies the operating mode for the selected pins.
									   This parameter can be a value of @ref GPIOMode_TypeDef */
	GPIOControl_TypeDef GPIO_Ctrl;    /*!< Specifies the control mode for the selected pins.
									   This parameter can be a value of @ref GPIOControl_TypeDef */
	GPIOOType_TypeDef GPIO_OType;   /*!< Specifies the operating output type for the selected pins.
										This parameter can be a value of @ref GPIOOType_TypeDef */
	GPIOPuPd_TypeDef GPIO_PuPd; 	/*!< Specifies the operating Pull-up/Pull down for the selected pins.
										 This parameter can be a value of @ref GPIOPuPd_TypeDef */
	GPIOInit_Level GPIO_Level;  /*!< Specifies the gpio init level for the selected pins.
										  This parameter can be a value of @ref GPIOInit_Level */
}GPIO_InitTypeDef;

/***************************************************************
*  Set IO multi-function
*  PinCFG: out:PORT->PA00CFG, PA01CFG, ....PH04CFG
*   			 in :PORT->TI00PCFG,RXD0PCFG, ....INTP7PCFG
*  MuxMode: GROUP_AF_ODEFAULT,GROUP_AF_GPIO, .....,PORTINPUT_CFG_PB00
******************************************************************/
#define SYS_SET_IOCFG(PinCFG, MuxMode)	PinCFG = MuxMode;


void GPIO_Output_Enable(__IO uint16_t *port, uint16_t pinMsk);
void GPIO_Output_Disable(__IO uint16_t *port, uint16_t pinMsk);
void GPIO_Input_Enable(__IO uint16_t *port, uint16_t pinMsk);
void GPIO_PullUp_Enable(__IO uint16_t *port, uint16_t pinMsk);
void GPIO_PullUp_Disable(__IO uint16_t *port, uint16_t pinMsk);
void GPIO_PullDown_Enable(__IO uint16_t *port, uint16_t pinMsk);
void GPIO_PullDown_Disable(__IO uint16_t *port, uint16_t pinMsk);
void GPIO_Set_Value(__IO uint16_t *port, uint16_t value);
void GPIO_Nch_OpenDrain(__IO uint16_t *port, uint16_t pinMsk);
void GPIO_SetBits(GPIO_Port_t  PORTx, uint16_t GPIO_Pin);

uint8_t GPIO_ReadInputDataBit(GPIO_Port_t PORTx, uint16_t GPIO_Pin);
uint8_t GPIO_ReadOutputDataBit(GPIO_Port_t PORTx, uint16_t GPIO_Pin);
void GPIO_SetBits(GPIO_Port_t  PORTx, uint16_t GPIO_Pin);
void GPIO_ResetBits(GPIO_Port_t PORTx, uint16_t GPIO_Pin);
void GPIO_Init(GPIO_Port_t PORTx,GPIO_InitTypeDef* GPIO_InitStruct);
void GPIO_ToggleBits(GPIO_Port_t PORTx, uint16_t GPIO_Pin);




#endif

