#include "intp.h"

/**
  * @brief  This function initializes the external interrupt module.
  * @param  Intp_InitStruct: pointer to a INTP_InitTypeDef structure that contains
  *         the configuration information for the specified INTP peripheral.
  * @retval None
  */
void INTP_Init(INTP_InitTypeDef* Intp_InitStruct)
{
	volatile uint8_t w_count;
	uint16_t pinpos = 0x00,pinnum=0x00, pos = 0x00, currentpin = 0x00;

    /* Check the parameters */
    assert_param(IS_INTP_TYPE(Intp_InitStruct->INTP_Select));
	for(pinpos = 0x00; pinpos < 0x08; pinpos++)
	{
		pos = ((uint16_t)0x01) << pinpos;
		pinnum = Intp_InitStruct->INTP_Select & pos;
		if(pinnum == pos)
		{
			currentpin = pinpos;
		}
	}
	
	INTM->EGN0 &= ~Intp_InitStruct->INTP_Select;
	INTM->EGP0 &= ~Intp_InitStruct->INTP_Select;
	
	INTM->EGN0 |= ((Intp_InitStruct->EXTI_Trigger & 0x01U) >> 0) << currentpin;
	INTM->EGP0 |= ((Intp_InitStruct->EXTI_Trigger & 0x02U) >> 1) << currentpin;	
	if(Intp_InitStruct->INTP_Select == INTP0)
	{
		MISC->ISC &= ~MISC_ISC_ISC0_Msk;
		if(Intp_InitStruct->INTP0_Port == INTP0_RXD0)
			MISC->ISC |= MISC_ISC_ISC0_Msk;
		for (w_count = 0U; w_count <= KEY_WAITTIME; w_count++)
	{   
			__NOP();
	}	
	}
}

/**
  * @brief  This function select INTP0 interrupt input.
  * @param  INTP0IN:select the INTP0 trigger port
  * 	@arg  INTP0_GPIO/INTP0_RXD0
  * @retval None
  */
void INTP0_Input_Select(INTP0_InputDef INTP0IN)
{
	volatile uint8_t w_count;
	
	if(INTP0IN == INTP0_GPIO)
	{
			MISC->ISC &= ~MISC_ISC_ISC0_Msk;			//ѡINTP0źΪⲿж0	
	}
	else
	{
			MISC->ISC |= MISC_ISC_ISC0_Msk;			//ѡRXD0źΪⲿж0
	}	
	for (w_count = 0U; w_count <= KEY_WAITTIME; w_count++)
	{   
			__NOP();
	}		
	
}

/**
  * @brief  This function clears INTP interrupt flag and enables interrupt.
  * @param  pinMsk:select the active external interrupt pins
  * 	@arg  INTP0/INTP1/INTP2/INTP3/INTP4/INTP5
  * @retval None
  */
void INTP_Start(uint16_t pinMsk)
{
    if(pinMsk & (1 << 0))
    {
        INTC_ClearPendingIRQ(INTP0_IRQn); /* clear INTP interrupt flag */
				INTC_SetPendingIRQ(INTP0_IRQn); 
        INTC_EnableIRQ(INTP0_IRQn);       /* enable INTP interrupt */
			
    }
    if(pinMsk & (1 << 1))
    {
        INTC_ClearPendingIRQ(INTP1_IRQn); /* clear INTP interrupt flag */
				INTC_SetPendingIRQ(INTP1_IRQn); 
        INTC_EnableIRQ(INTP1_IRQn);       /* enable INTP interrupt */
    }
    if(pinMsk & (1 << 2))
    {
        INTC_ClearPendingIRQ(INTP2_IRQn); /* clear INTP interrupt flag */
				INTC_SetPendingIRQ(INTP2_IRQn); 
        INTC_EnableIRQ(INTP2_IRQn);       /* enable INTP interrupt */
    }
    if(pinMsk & (1 << 3))
    {
        INTC_ClearPendingIRQ(INTP3_IRQn); /* clear INTP interrupt flag */
				INTC_SetPendingIRQ(INTP3_IRQn); 
        INTC_EnableIRQ(INTP3_IRQn);       /* enable INTP interrupt */
    }
		if(pinMsk & (1 << 4))
    {
        INTC_ClearPendingIRQ(INTP4_IRQn); /* clear INTP interrupt flag */
				INTC_SetPendingIRQ(INTP4_IRQn);
        INTC_EnableIRQ(INTP4_IRQn);       /* enable INTP interrupt */
    }
		if(pinMsk & (1 << 5))
    {
        INTC_ClearPendingIRQ(INTP5_IRQn); /* clear INTP interrupt flag */
//				INTC_SetPendingIRQ(INTP5_IRQn);  	//open this sentence for interrupt except sigmadelta adc
        INTC_EnableIRQ(INTP5_IRQn);       /* enable INTP interrupt */
    }
		if(pinMsk & (1 << 6))
    {
        INTC_ClearPendingIRQ(INTP6_IRQn); /* clear INTP interrupt flag */
				INTC_SetPendingIRQ(INTP6_IRQn); 
        INTC_EnableIRQ(INTP6_IRQn);       /* enable INTP interrupt */
    }
		if(pinMsk & (1 << 7))
    {
        INTC_ClearPendingIRQ(INTP7_IRQn); /* clear INTP interrupt flag */
				INTC_SetPendingIRQ(INTP7_IRQn); 
        INTC_EnableIRQ(INTP7_IRQn);       /* enable INTP interrupt */
    }
}

/**
  * @brief  This function disables INTP interrupt and clears interrupt flag.
  * @param  pinMsk:select the active external interrupt pins
  * 	@arg  INTP0/INTP1/INTP2/INTP3/INTP4/INTP5
  * @retval None
  */
void INTP_Stop(uint16_t pinMsk)
{
    if(pinMsk & (1 << 0))
    {
        INTC_DisableIRQ(INTP0_IRQn);       /* disable INTP interrupt */
        INTC_ClearPendingIRQ(INTP0_IRQn);  /* clear INTP interrupt flag */
    }
    if(pinMsk & (1 << 1))
    {
        INTC_DisableIRQ(INTP1_IRQn);       /* disable INTP interrupt */
        INTC_ClearPendingIRQ(INTP1_IRQn);  /* clear INTP interrupt flag */
    }
    if(pinMsk & (1 << 2))
    {
        INTC_DisableIRQ(INTP2_IRQn);       /* disable INTP interrupt */
        INTC_ClearPendingIRQ(INTP2_IRQn);  /* clear INTP interrupt flag */
    }
    if(pinMsk & (1 << 3))
    {
        INTC_DisableIRQ(INTP3_IRQn);       /* disable INTP interrupt */
        INTC_ClearPendingIRQ(INTP3_IRQn);  /* clear INTP interrupt flag */
    }
    if(pinMsk & (1 << 4))
    {
        INTC_DisableIRQ(INTP4_IRQn);       /* disable INTP interrupt */
        INTC_ClearPendingIRQ(INTP4_IRQn);  /* clear INTP interrupt flag */
    }		
    if(pinMsk & (1 << 5))
    {
        INTC_DisableIRQ(INTP5_IRQn);       /* disable INTP interrupt */
        INTC_ClearPendingIRQ(INTP5_IRQn);  /* clear INTP interrupt flag */
    }		
		if(pinMsk & (1 << 6))
    {
        INTC_DisableIRQ(INTP6_IRQn);       /* disable INTP interrupt */
        INTC_ClearPendingIRQ(INTP6_IRQn);  /* clear INTP interrupt flag */
    }	
		if(pinMsk & (1 << 7))
    {
        INTC_DisableIRQ(INTP7_IRQn);       /* disable INTP interrupt */
        INTC_ClearPendingIRQ(INTP7_IRQn);  /* clear INTP interrupt flag */
    }	
		
}
