/*******************************************************************************
*                  COPYRIGHT (C) 2021 CMS Technologies Ltd.                    *
*                                                                              *
********************************************************************************
* FileName      : iic_demo.c                                                   *
* Author        :                                                              *
* Version       : 1.0                                                          *
* Date          : 2021.08.13                                                   *
* Description   :                                                              *
* Function List :                                                              *
********************************************************************************/
#include "iic_demo.h"
static IIC_FRAME_t pIData; /*pIData used as an example,user can dinfine different paramater according to needs*/

volatile uint8_t g_iic_tx_end;                /* iic send data end */
volatile uint8_t g_iic_rx_end;                /* iic receive data end */
volatile uint16_t g_iic_rx_count = 0;

int8_t Iic01_Init(void)
{
    int8_t res ;
    GPIO_InitTypeDef GPIO_InitStruct = {0};
    I2C_InitTypeDef  IIC_InitStructure = {0};
		
		GPIO_PinAFConfig(PORT->PA14CFG, GROUP_AF_ODEFAULT);					//config SCL01 to PA14
		GPIO_PinAFConfig(PORT->PA13CFG, GROUP_AF_ODEFAULT);					//config SDA01 to PA13
    /*SCL01/SDA01 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_13|GPIO_Pin_14;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level = GPIO_Level_HIGH;
    GPIO_InitStruct.GPIO_OType = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTA, &GPIO_InitStruct);

    IIC_InitStructure.I2C_ClockSpeed = 100000;
    res = I2C_Init(I2C01, &IIC_InitStructure);

    if (res)
    {
        SCI_ERROR_LOG(res);
        return res;
    }
		
#ifdef IIC_USING_INTERRUPT
    ISR_Register(IIC01_IRQn,iic01_interrupt); //жϷ·ע
#endif
    return SCI_SUCCESS;
}

int8_t Iic11_Init(void)
{
    int8_t res ;
    GPIO_InitTypeDef GPIO_InitStruct = {0};
    I2C_InitTypeDef  IIC_InitStructure;

		GPIO_PinAFConfig(PORT->PC03CFG, GROUP_AF_ODEFAULT);					//config SCL11 to PC03
		GPIO_PinAFConfig(PORT->PC05CFG, GROUP_AF_ODEFAULT);					//config SDA11 to PC05
		
    /*SCL11/SDA11 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_3|GPIO_Pin_5;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level = GPIO_Level_HIGH;
    GPIO_InitStruct.GPIO_OType = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTC, &GPIO_InitStruct);

    IIC_InitStructure.I2C_ClockSpeed = 100000;
    res = I2C_Init(I2C11, &IIC_InitStructure);

    if (res)
    {
        SCI_ERROR_LOG(res);
        return res;
    }
#ifdef IIC_USING_INTERRUPT
    ISR_Register(IIC11_IRQn,iic11_interrupt); //жϷ·ע
#endif
    return SCI_SUCCESS;
}

int8_t Iic21_Init(void)
{
    int8_t res ;
    GPIO_InitTypeDef GPIO_InitStruct = {0};
    I2C_InitTypeDef  IIC_InitStructure;

		GPIO_PinAFConfig(PORT->PB03CFG, GROUP_AF_ODEFAULT);					//config SCL21 to PB03
		GPIO_PinAFConfig(PORT->PB04CFG, GROUP_AF_ODEFAULT);					//config SDA21 to PB04
		
    /*SCL21/SDA21 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_3|GPIO_Pin_4;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level = GPIO_Level_HIGH;
    GPIO_InitStruct.GPIO_OType = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTB, &GPIO_InitStruct);

    IIC_InitStructure.I2C_ClockSpeed = 100000;
    res = I2C_Init(I2C21, &IIC_InitStructure);

    if (res)
    {
        SCI_ERROR_LOG(res);
        return res;
    }
#ifdef IIC_USING_INTERRUPT
    ISR_Register(IIC21_IRQn,iic21_interrupt); //жϷ·ע
#endif
    return SCI_SUCCESS;
}

/***********************************************************************************************************************
* Function Name: Iic01_Write
* @brief  This function starts transferring data for IIC in master mode.
* @param  address - set address for select slave
* @param  tx_buf - transfer buffer pointer
* @param  tx_num - buffer size
* @return None
***********************************************************************************************************************/
void Iic01_Write(uint8_t address, uint8_t *tx_buf, uint16_t tx_num)
{
    pIData.flag = IIC_INT_IDLE;
    address &= 0xFE;    //iic write flag

    I2C_Set_TransmitMode(I2C01, I2C_TransmitMode_Send);
    I2C_GenerateSTART(I2C01);

    INTC_ClearPendingIRQ(IIC01_IRQn); // clear INTIIC01 interrupt flag
    NVIC_ClearPendingIRQ(IIC01_IRQn); // clear INTIIC01 interrupt flag
    INTC_EnableIRQ(IIC01_IRQn);     // enable INTIIC01 interrupt flag
    NVIC_SetPriority(IIC01_IRQn, 3);  /* low priority */

    I2C_SendByte(I2C01, address);

    g_iic_tx_end = 0;
    pIData.flag = IIC_INT_TX;
    pIData.data = tx_buf;    //send buffer pointer
    pIData.len  = tx_num;    //set send data count
}

/***********************************************************************************************************************
* Function Name: Iic11_Write
* @brief  This function starts transferring data for IIC in master mode.
* @param  address - set address for select slave
* @param  tx_buf - transfer buffer pointer
* @param  tx_num - buffer size
* @return None
***********************************************************************************************************************/
void Iic11_Write(uint8_t address, uint8_t *tx_buf, uint16_t tx_num)
{
    pIData.flag = IIC_INT_IDLE;
    address &= 0xFE;    //iic write flag

    I2C_Set_TransmitMode(I2C11, I2C_TransmitMode_Send);
    I2C_GenerateSTART(I2C11);

    INTC_ClearPendingIRQ(IIC11_IRQn); // clear INTIIC11 interrupt flag
    NVIC_ClearPendingIRQ(IIC11_IRQn); // clear INTIIC11 interrupt flag
    INTC_EnableIRQ(IIC11_IRQn);     // enable INTIIC11 interrupt flag
    NVIC_SetPriority(IIC11_IRQn, 3);  /* low priority */

    I2C_SendByte(I2C11, address);

    g_iic_tx_end = 0;
    pIData.flag = IIC_INT_TX;
    pIData.data = tx_buf;    //send buffer pointer
    pIData.len  = tx_num;    //set send data count
}

/***********************************************************************************************************************
* Function Name: Iic21_Write
* @brief  This function starts transferring data for IIC in master mode.
* @param  address - set address for select slave
* @param  tx_buf - transfer buffer pointer
* @param  tx_num - buffer size
* @return None
***********************************************************************************************************************/
void Iic21_Write(uint8_t address, uint8_t *tx_buf, uint16_t tx_num)
{
    pIData.flag = IIC_INT_IDLE;
    address &= 0xFE;    //iic write flag

    I2C_Set_TransmitMode(I2C21, I2C_TransmitMode_Send);
    I2C_GenerateSTART(I2C21);

    INTC_ClearPendingIRQ(IIC21_IRQn); // clear INTIIC21 interrupt flag
    NVIC_ClearPendingIRQ(IIC21_IRQn); // clear INTIIC21 interrupt flag
    INTC_EnableIRQ(IIC21_IRQn);     // enable INTIIC21 interrupt flag
    NVIC_SetPriority(IIC21_IRQn, 3);  /* low priority */

    I2C_SendByte(I2C21, address);

    g_iic_tx_end = 0;
    pIData.flag = IIC_INT_TX;
    pIData.data = tx_buf;    //send buffer pointer
    pIData.len  = tx_num;    //set send data count
}

/***********************************************************************************************************************
* Function Name: Iic01_Read
* @brief  This function starts receiving data for IIC in master mode.
* @param  address - set address for select slave
* @param  rx_buf - receive buffer pointer
* @param  rx_num - buffer size
* @return None
***********************************************************************************************************************/
void Iic01_Read(uint8_t address, uint8_t *rx_buf, uint16_t rx_num)
{
    pIData.flag = IIC_INT_IDLE;
    address |= 0x01;    //iic read flag

    I2C_Set_TransmitMode(I2C01, I2C_TransmitMode_Send);
    I2C_GenerateSTART(I2C01);

    INTC_ClearPendingIRQ(IIC01_IRQn); // clear INTIIC01 interrupt flag
    NVIC_ClearPendingIRQ(IIC01_IRQn); // clear INTIIC01 interrupt flag
    INTC_EnableIRQ(IIC01_IRQn);     // enable INTIIC01 interrupt flag

    I2C_SendByte(I2C01, address);

    g_iic_rx_end = 0;
    g_iic_rx_count = 0;
    pIData.flag = IIC_INT_RX;
    pIData.data = rx_buf;    //send buffer pointer
    pIData.len  = rx_num;    //set send data count
}

/***********************************************************************************************************************
* Function Name: Iic11_Read
* @brief  This function starts receiving data for IIC in master mode.
* @param  address - set address for select slave
* @param  rx_buf - receive buffer pointer
* @param  rx_num - buffer size
* @return None
***********************************************************************************************************************/
void Iic11_Read(uint8_t address, uint8_t *rx_buf, uint16_t rx_num)
{
    pIData.flag = IIC_INT_IDLE;
    address |= 0x01;    //iic read flag

    I2C_Set_TransmitMode(I2C11, I2C_TransmitMode_Send);
    I2C_GenerateSTART(I2C11);

    INTC_ClearPendingIRQ(IIC11_IRQn); // clear INTIIC11 interrupt flag
    NVIC_ClearPendingIRQ(IIC11_IRQn); // clear INTIIC11 interrupt flag
    INTC_EnableIRQ(IIC11_IRQn);     // enable INTIIC11 interrupt flag

    I2C_SendByte(I2C11, address);

    g_iic_rx_end = 0;
    g_iic_rx_count = 0;
    pIData.flag = IIC_INT_RX;
    pIData.data = rx_buf;    //send buffer pointer
    pIData.len  = rx_num;    //set send data count
}

/***********************************************************************************************************************
* Function Name: Iic21_Read
* @brief  This function starts receiving data for IIC in master mode.
* @param  address - set address for select slave
* @param  rx_buf - receive buffer pointer
* @param  rx_num - buffer size
* @return None
***********************************************************************************************************************/
void Iic21_Read(uint8_t address, uint8_t *rx_buf, uint16_t rx_num)
{
    pIData.flag = IIC_INT_IDLE;
    address |= 0x01;    //iic read flag

    I2C_Set_TransmitMode(I2C21, I2C_TransmitMode_Send);
    I2C_GenerateSTART(I2C21);

    INTC_ClearPendingIRQ(IIC21_IRQn); // clear INTIIC21 interrupt flag
    NVIC_ClearPendingIRQ(IIC21_IRQn); // clear INTIIC21 interrupt flag
    INTC_EnableIRQ(IIC21_IRQn);     // enable INTIIC21 interrupt flag

    I2C_SendByte(I2C21, address);

    g_iic_rx_end = 0;
    g_iic_rx_count = 0;
    pIData.flag = IIC_INT_RX;
    pIData.data = rx_buf;    //send buffer pointer
    pIData.len  = rx_num;    //set send data count
}

static void iic_callback_master_error(uint8_t flag)
{
    /* Start user code. Do not edit comment generated here */
    /* End user code. Do not edit comment generated here */
}

void iic01_interrupt(void)
{
    IIC_FRAME_t *pFrame = &pIData;


    if ((I2C_GetErrStaus(I2C01, I2C_FLAG_NOACK) == SET) && (pFrame->len != 0))   
    {
        iic_callback_master_error(IIC_NO_ACK); // NO IIC ACK is received
    }
    else if ((I2C_GetErrStaus(I2C01, I2C_FLAG_OVERRUN) == SET)  && (pFrame->len != 0))
    {
        iic_callback_master_error(IIC_OVF_RUN);
    }
    else/* IIC ACK is received*/
    {
        /* Control for master send */
        if (pFrame->flag == IIC_INT_TX)
        {
            if (pFrame->len > 0U)
            {
                I2C_SendByte(I2C01, *pFrame->data);
                pFrame->data++;
                pFrame->len--;
            }
            else //IIC01 finishes master transmission
            {
                I2C_GenerateSTOP(I2C01);
                g_iic_tx_end = 1;
                pFrame->flag = 0;
            }
        }
        else  // Control for master receive
        {
            if ((pFrame->flag & SCI_IIC_SENDADR) == 0)
            {
                I2C_ChannelStart_Cmd(I2C01, DISABLE);       //رͨ
                I2C_Set_TransmitMode(I2C01, I2C_TransmitMode_Recv);//Ϊ
                I2C_ChannelStart_Cmd(I2C01, ENABLE);        //ͨ

                pFrame->flag |= SCI_IIC_SENDADR;

                if (pFrame->len == 1)
                {
                    I2C_Output_Cmd(I2C01, DISABLE);  //ͨ
                }

                I2C_SendByte(I2C01, 0xFFU);
            }
            else
            {
                if (g_iic_rx_count < pFrame->len)
                {
                    *pFrame->data = I2C_ReceiveByte(I2C01);
                    pFrame->data++;
                    g_iic_rx_count++;

                    if (g_iic_rx_count == (pFrame->len - 1))
                    {
                        I2C_Output_Cmd(I2C01, DISABLE);
                        I2C_SendByte(I2C01, 0xFFU);
                    }
                    else if (g_iic_rx_count == pFrame->len)
                    {
                        I2C_GenerateSTOP(I2C01);
                        g_iic_rx_end = 1;
                    }
                    else
                    {
                        I2C_SendByte(I2C01, 0xFFU);
                    }
                }
            }
        }
    }

    INTC_ClearPendingIRQ(IIC01_IRQn);
}

void iic11_interrupt(void)
{
    IIC_FRAME_t *pFrame = &pIData;


    if ((I2C_GetErrStaus(I2C11, I2C_FLAG_NOACK) == SET) && (pFrame->len != 0))   
    {
        iic_callback_master_error(IIC_NO_ACK); // NO IIC ACK is received
    }
    else if ((I2C_GetErrStaus(I2C11, I2C_FLAG_OVERRUN) == SET)  && (pFrame->len != 0))
    {
        iic_callback_master_error(IIC_OVF_RUN);
    }
    else/* IIC ACK is received*/
    {
        /* Control for master send */
        if (pFrame->flag == IIC_INT_TX)
        {
            if (pFrame->len > 0U)
            {
                I2C_SendByte(I2C11, *pFrame->data);
                pFrame->data++;
                pFrame->len--;
            }
            else //IIC11 finishes master transmission
            {
                I2C_GenerateSTOP(I2C11);
                g_iic_tx_end = 1;
                pFrame->flag = 0;
            }
        }
        else  // Control for master receive
        {
            if ((pFrame->flag & SCI_IIC_SENDADR) == 0)
            {
                I2C_ChannelStart_Cmd(I2C11, DISABLE);       //رͨ
                I2C_Set_TransmitMode(I2C11, I2C_TransmitMode_Recv);//Ϊ
                I2C_ChannelStart_Cmd(I2C11, ENABLE);        //ͨ

                pFrame->flag |= SCI_IIC_SENDADR;

                if (pFrame->len == 1)
                {
                    I2C_Output_Cmd(I2C11, DISABLE);  //ͨ
                }

                I2C_SendByte(I2C11, 0xFFU);
            }
            else
            {
                if (g_iic_rx_count < pFrame->len)
                {
                    *pFrame->data = I2C_ReceiveByte(I2C11);
                    pFrame->data++;
                    g_iic_rx_count++;

                    if (g_iic_rx_count == (pFrame->len - 1))
                    {
                        I2C_Output_Cmd(I2C11, DISABLE);
                        I2C_SendByte(I2C11, 0xFFU);
                    }
                    else if (g_iic_rx_count == pFrame->len)
                    {
                        I2C_GenerateSTOP(I2C11);
                        g_iic_rx_end = 1;
                    }
                    else
                    {
                        I2C_SendByte(I2C11, 0xFFU);
                    }
                }
            }
        }
    }

    INTC_ClearPendingIRQ(IIC11_IRQn);
}

void iic21_interrupt(void)
{
    IIC_FRAME_t *pFrame = &pIData;


    if ((I2C_GetErrStaus(I2C21, I2C_FLAG_NOACK) == SET) && (pFrame->len != 0))   
    {
        iic_callback_master_error(IIC_NO_ACK); // NO IIC ACK is received
    }
    else if ((I2C_GetErrStaus(I2C21, I2C_FLAG_OVERRUN) == SET)  && (pFrame->len != 0))
    {
        iic_callback_master_error(IIC_OVF_RUN);
    }
    else/* IIC ACK is received*/
    {
        /* Control for master send */
        if (pFrame->flag == IIC_INT_TX)
        {
            if (pFrame->len > 0U)
            {
                I2C_SendByte(I2C21, *pFrame->data);
                pFrame->data++;
                pFrame->len--;
            }
            else //IIC21 finishes master transmission
            {
                I2C_GenerateSTOP(I2C21);
                g_iic_tx_end = 1;
                pFrame->flag = 0;
            }
        }
        else  // Control for master receive
        {
            if ((pFrame->flag & SCI_IIC_SENDADR) == 0)
            {
                I2C_ChannelStart_Cmd(I2C21, DISABLE);       //رͨ
                I2C_Set_TransmitMode(I2C21, I2C_TransmitMode_Recv);//Ϊ
                I2C_ChannelStart_Cmd(I2C21, ENABLE);        //ͨ

                pFrame->flag |= SCI_IIC_SENDADR;

                if (pFrame->len == 1)
                {
                    I2C_Output_Cmd(I2C21, DISABLE);  //ͨ
                }

                I2C_SendByte(I2C21, 0xFFU);
            }
            else
            {
                if (g_iic_rx_count < pFrame->len)
                {
                    *pFrame->data = I2C_ReceiveByte(I2C21);
                    pFrame->data++;
                    g_iic_rx_count++;

                    if (g_iic_rx_count == (pFrame->len - 1))
                    {
                        I2C_Output_Cmd(I2C21, DISABLE);
                        I2C_SendByte(I2C21, 0xFFU);
                    }
                    else if (g_iic_rx_count == pFrame->len)
                    {
                        I2C_GenerateSTOP(I2C21);
                        g_iic_rx_end = 1;
                    }
                    else
                    {
                        I2C_SendByte(I2C21, 0xFFU);
                    }
                }
            }
        }
    }

    INTC_ClearPendingIRQ(IIC21_IRQn);
}
