#include "iica_demo.h"
volatile uint8_t   g_iica_tx_end;             /* iica0 send data end */
volatile uint8_t   g_iica_rx_end;             /* iica0 receive data end */
uint16_t  g_iica_rx_cnt;                     /* iica1 receive data count */

#define _80_IICA_ADDRESS_COMPLETE                     (0x80U)
#define _00_IICA_MASTER_FLAG_CLEAR                    (0x00U)

void Iica0_Init(void)
{
    GPIO_InitTypeDef GPIO_InitStruct = {0};
    I2CA_InitTypeDef I2CA_InitStructure;

		GPIO_PinAFConfig(PORT->SCLA0PCFG, PORTINPUT_CFG_PC10);		//SCLA0 can be allocated to any desired pins in group0
		GPIO_PinAFConfig(PORT->SDAA0PCFG, PORTINPUT_CFG_PC11);		//SDAA0 can be allocated to any desired pins in group0
		
    /*SCLA0 SDAA0 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_10| GPIO_Pin_11;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level  = GPIO_Level_LOW;
    GPIO_InitStruct.GPIO_PuPd   = GPIO_PuPd_UP;
    GPIO_InitStruct.GPIO_OType  = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTC, &GPIO_InitStruct);

		I2CA_InitStructure.IIC_Channel = I2CA0;
    I2CA_InitStructure.I2C_ClockSpeed = 10000;
    I2CA_InitStructure.I2C_Ack = I2CA_Ack_Enable;
    I2CA_InitStructure.I2C_DutyCycle = 50;
    I2CA_InitStructure.I2C_OwnAddress = 0xA0;
    I2CA_InitStructure.I2C_Mode = I2CA_Mode_SMBusMaster;
    I2CA_Init(&I2CA_InitStructure);
#ifdef I2CA_USING_INTERRUPT
    ISR_Register(IICA0_IRQn, iica0_interrupt);
#endif
}


void Iica1_Init(void)
{
    GPIO_InitTypeDef GPIO_InitStruct = {0};
    I2CA_InitTypeDef I2CA_InitStructure;

		GPIO_PinAFConfig(PORT->SCLA1PCFG, PORTINPUT_CFG_PB06);		//SCLA1 can be allocated to any desired pins in group2
		GPIO_PinAFConfig(PORT->SDAA1PCFG, PORTINPUT_CFG_PB05);		//SDAA1 can be allocated to any desired pins in group2
		
    /*SCLA0 SDAA0 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_6| GPIO_Pin_5;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level  = GPIO_Level_LOW;
    GPIO_InitStruct.GPIO_PuPd   = GPIO_PuPd_UP;
    GPIO_InitStruct.GPIO_OType  = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTB, &GPIO_InitStruct);

		I2CA_InitStructure.IIC_Channel = I2CA1;
    I2CA_InitStructure.I2C_ClockSpeed = 100000;
    I2CA_InitStructure.I2C_Ack = I2CA_Ack_Enable;
    I2CA_InitStructure.I2C_DutyCycle = 50;
    I2CA_InitStructure.I2C_OwnAddress = 0xA0;
    I2CA_InitStructure.I2C_Mode = I2CA_Mode_SMBusMaster;
    I2CA_Init(&I2CA_InitStructure);
#ifdef I2CA_USING_INTERRUPT
    ISR_Register(IICA1_IRQn, iica1_interrupt);
#endif
}

/***********************************************************************************************************************
* Function Name: IICA_MasterWrite
* @brief  This function starts to write data by interrupt as master mode.
* @param  adr - send address
* @param  tx_buf - transfer buffer pointer
* @param  tx_num - buffer size
* @param  wait :wait for start condition
* @return status
*             - MD_OK or MD_ERROR1 or MD_ERROR2
***********************************************************************************************************************/
int IICA_MasterWrite(I2CA_Typr IICx,uint8_t adr, uint8_t *tx_buf, uint16_t tx_num, uint8_t wait)
{
    I2CA_Status status = OK;

    if (I2CA_GetFlagStaus(IICx,I2CA_STATUS_BUSBSY) != RESET)
    {
        status = BUSY;
    }
    else
    {
        I2CA_GenerateSTART(IICx);
//				INTC_EnableIRQ(IICA_IRQn);   /* enable INTIICA0 interrupt */
        /* Wait */
        while (wait--)
        {
            ;
        }

        if (RESET == I2CA_GetFlagStaus(IICx,I2CA_STATUS_STD))   //if start condition does not occur
        {
            status = NSTART;
        }

        /* Set parameter */
        pData.data = tx_buf;
        pData.len = tx_num;
        pData.flag = INT_IDLE;
        g_iica_tx_end = 0;

        adr &= (uint8_t)0xFE;    // set write mode
				if(IICx == I2CA0)
					IICA0->IICAD0 = adr;      // write address
				else
					IICA1->IICAD1 = adr;      // write address
    }

    return (status);
}
/***********************************************************************************************************************
* Function Name: IICA_MasterRead
* @brief  This function starts to read data as master mode.
* @param  adr - receive address
* @param  rx_buf - transfer buffer pointer
* @param  rx_num - buffer size
* @param  wait :wait for start condition
* @return status
*             - MD_OK or MD_ERROR1 or MD_ERROR2
***********************************************************************************************************************/
int IICA_MasterReceive(I2CA_Typr IICx,uint8_t adr, uint8_t *const rx_buf, uint16_t rx_num, uint8_t wait)
{
    I2CA_Status status = OK;

		if(IICx == I2CA0)
			INTC_DisableIRQ(IICA0_IRQn);   // disable INTIICA0 interrupt
		else
			INTC_DisableIRQ(IICA1_IRQn);   // disable INTIICA1 interrupt

    if (I2CA_GetFlagStaus(IICx,I2CA_STATUS_BUSBSY) != RESET)
    {
        /* Check bus busy */
				if(IICx == I2CA0)
					INTC_EnableIRQ(IICA0_IRQn);   // enable INTIICA0 interrupt
				else
					INTC_EnableIRQ(IICA1_IRQn);   // enable INTIICA1 interrupt
        status = BUSY;
    }
    else
    {
        I2CA_GenerateSTART(IICx);     //generate a start condition
				if(IICx == I2CA0)
					INTC_EnableIRQ(IICA0_IRQn);   // enable INTIICA0 interrupt
				else
					INTC_EnableIRQ(IICA1_IRQn);   // enable INTIICA1 interrupt

        /* Wait */
        while (wait--)
        {
            ;
        }

        if (RESET == I2CA_GetFlagStaus(IICx,I2CA_STATUS_STD))   //check no start condition occurs
        {
            status = NSTART;
        }

        /* Set parameter */
        pData.data = rx_buf;
        pData.len = rx_num;
        pData.flag = INT_IDLE;

        g_iica_rx_end = 0;
        g_iica_rx_cnt = 0;
        adr |= (uint8_t)0x01;       // set receive mode
				if(IICx == I2CA0)
					IICA0->IICAD0 = adr;       // write address
				else
					IICA1->IICAD1 = adr;       // write address
    }

    return (status);
}

/***********************************************************************************************************************
* Function Name: IICA0_Clear_Wakeup
* @brief  This function clears the WUPn bit of IICCTL01 register.
* @param  None
* @return None
***********************************************************************************************************************/
void IICA0_Clear_Wakeup()
{
    IICA0->IICCTL01 &= ~0x80; // WUP = 0
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
}

/***********************************************************************************************************************
* Function Name: IICA1_Clear_Wakeup
* @brief  This function clears the WUPn bit of IICCTL11 register.
* @param  None
* @return None
***********************************************************************************************************************/
void IICA1_Clear_Wakeup()
{
    IICA1->IICCTL11 &= ~0x80; // WUP = 0
    __NOP();
    __NOP();
    __NOP();
    __NOP();
    __NOP();
}

/***********************************************************************************************************************
* Function Name: iica0_master_send_end
* @brief  This function is a callback function when IICA0 finishes master transmission.
* @param  None
* @return None
***********************************************************************************************************************/
static void iica_master_send_end(I2CA_Typr IICx)
{
		if(IICx == I2CA0)
			IICA0->IICCTL00 |= IICA0_IICCTL00_SPT_Msk;             // stop condition is generated
		else
			IICA1->IICCTL10 |= IICA1_IICCTL10_SPT_Msk;             // stop condition is generated

    while (0U == I2CA_GetFlagStaus(IICx,I2CA_STATUS_SPD));   // stop condition is detected

    g_iica_tx_end = 1;
}

/***********************************************************************************************************************
* Function Name: iica0_master_recv_end
* @brief  This function is a callback function when IICA0 finishes master reception.
* @param  None
* @return None
***********************************************************************************************************************/
static void iica_master_recv_end(I2CA_Typr IICx)
{
		if(IICx == I2CA0)
			IICA0->IICCTL00 |= IICA0_IICCTL00_SPT_Msk;             /* stop condition is generated */
		else
			IICA1->IICCTL10 |= IICA1_IICCTL10_SPT_Msk;             /* stop condition is generated */

    while (0U == I2CA_GetFlagStaus(IICx,I2CA_STATUS_SPD));   /* stop condition is detected */

    g_iica_rx_end = 1;
}


/***********************************************************************************************************************
* Function Name: iica_masterhandler
* @brief   This function is IICA0 master handler.
* @param  None
* @return None
***********************************************************************************************************************/
static void iica_master_error(I2CA_Status flag)
{
    /* Start user code. Do not edit comment generated here */
    /* End user code. Do not edit comment generated here */
}

static void iica_masterhandler(I2CA_Typr IICx,void *msg)
{
    ATE_FRAME_t *pFrame = (ATE_FRAME_t *)msg;


    if ((I2CA_GetFlagStaus(IICx,I2CA_STATUS_BUSBSY) == RESET) && (pFrame->len != 0U))// Control for communication
    {
        iica_master_error(NSTOP);//IICSTOP
    }
    else // Control for sended address
    {
        if ((pFrame->flag & _80_IICA_ADDRESS_COMPLETE) == 0U) //write address uncompleted
        {
            if (I2CA_GetFlagStaus(IICx,I2CA_STATUS_ACK) != RESET)    //check iic received askd signal
            {
                pFrame->flag |= _80_IICA_ADDRESS_COMPLETE;  //write address completed

                if (I2CA_GetFlagStaus(IICx,I2CA_STATUS_TRC))  //sendding status
                {
									  if(IICx == I2CA0)
											IICA0->IICCTL00 |= IICA0_IICCTL00_WTIM_Msk;     // interrupt request is generated at the ninth clock's falling edge
										else
											IICA1->IICCTL10 |= IICA1_IICCTL10_WTIM_Msk;     // interrupt request is generated at the ninth clock's falling edge

                    if (pFrame->len > 0)
                    {
												if(IICx == I2CA0)
													IICA0->IICAD0 = *pFrame->data;
												else
													IICA1->IICAD1 = *pFrame->data;
                        pFrame->data++;
                        pFrame->len--;
                    }
                    else
                    {
												if(IICx == I2CA0)
													iica_master_send_end(I2CA0);//iic master send finished
												else
													iica_master_send_end(I2CA1);//iic master send finished
                    }
                }
                else          //receiving status
                {
										if(IICx == I2CA0)
										{
											IICA0->IICCTL00 |= IICA0_IICCTL00_ACKE_Msk;      // enable acknowledgment
											IICA0->IICCTL00 &= ~IICA0_IICCTL00_WTIM_Msk;    // interrupt request is generated at the eighth clock's falling edge
											IICA0->IICCTL00 |= IICA0_IICCTL00_WREL_Msk;     // cancel wait
										}
										else
										{
											IICA1->IICCTL10 |= IICA1_IICCTL10_ACKE_Msk;      // enable acknowledgment
											IICA1->IICCTL10 &= ~IICA1_IICCTL10_WTIM_Msk;    // interrupt request is generated at the eighth clock's falling edge
											IICA1->IICCTL10 |= IICA1_IICCTL10_WREL_Msk;     // cancel wait
										}
                }
            }
            else
            {
                iica_master_error(NACK);//iic no ack
            }
        }
        else    //write address completed
        {
            if (I2CA_GetFlagStaus(IICx,I2CA_STATUS_TRC))  // master in sending status
            {
                if ((0U == I2CA_GetFlagStaus(IICx,I2CA_STATUS_ACK)) && (pFrame->len != 0U))
                {
                    iica_master_error(NACK);//iic no ack
                }
                else
                {
                    if (pFrame->len > 0U)
                    {
												if(IICx == I2CA0)
													IICA0->IICAD0 = *pFrame->data;
												else
													IICA1->IICAD1 = *pFrame->data;
                        pFrame->data++;
                        pFrame->len--;
                    }
                    else
                    {
												if(IICx == I2CA0)
													iica_master_send_end(I2CA0);//iic master send finished
												else
													iica_master_send_end(I2CA1);//iic master send finished
                    }
                }
            }
            else     //master receive control
            {
                if (g_iica_rx_cnt < pFrame->len)
                {
										if(IICx == I2CA0)
											*pFrame->data = IICA0->IICAD0;
										else
											*pFrame->data = IICA1->IICAD1;
                    pFrame->data++;
                    g_iica_rx_cnt++;

                    if (g_iica_rx_cnt == pFrame->len)
                    {
												if(IICx == I2CA0)
												{
													IICA0->IICCTL00 &= ~IICA0_IICCTL00_ACKE_Msk;   // disable acknowledgment
													IICA0->IICCTL00 |= IICA0_IICCTL00_WREL_Msk;    // cancel wait
													IICA0->IICCTL00 |= IICA0_IICCTL00_WTIM_Msk;    //interrupt request is generated at the eighth clock's falling edge
												}
												else
												{
													IICA1->IICCTL10 &= ~IICA1_IICCTL10_ACKE_Msk;   // disable acknowledgment
													IICA1->IICCTL10 |= IICA1_IICCTL10_WREL_Msk;    // cancel wait
													IICA1->IICCTL10 |= IICA1_IICCTL10_WTIM_Msk;    //interrupt request is generated at the eighth clock's falling edge
												}
                    }
                    else
                    {
												if(IICx == I2CA0)
													IICA0->IICCTL00 |= IICA0_IICCTL00_WREL_Msk;     // cancel wait
												else
													IICA1->IICCTL10 |= IICA1_IICCTL10_WREL_Msk;     // cancel wait
                    }
                }
                else
                {
										if(IICx == I2CA0)
											iica_master_recv_end(I2CA0);//iic received finished
										else
											iica_master_recv_end(I2CA1);//iic received finished
                }
            }
        }
    }
}


void iica0_interrupt(void *msg)
{
    INTC_ClearPendingIRQ(IICA0_IRQn);
    IICA0_Clear_Wakeup();

    if ((IICA0->IICS0 & 0x80) == 0x80U)
    {
        iica_masterhandler(I2CA0,(void *)msg);
    }
    else
    {

    }
}


void iica1_interrupt(void *msg)
{
    INTC_ClearPendingIRQ(IICA1_IRQn);
    IICA1_Clear_Wakeup();

    if ((IICA1->IICS1 & 0x80) == 0x80U)
    {
        iica_masterhandler(I2CA1,(void *)msg);
    }
    else
    {

    }
}