/***********************************************************************************************************************
* Copyright (C) . All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : lcd.c
* Version      :  
* Device(s)    : CMS32H3201
* Tool-Chain   : MDK(armcc)
* Description  : lcd driver function.
* Creation Date: 2019/12/01
***********************************************************************************************************************/

/***********************************************************************************************************************
Macro Definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/

#include <stdio.h>
#include "CMS32H3201.h"
#include "lcd.h"
#include "lcdpannel.h"

extern volatile uint16_t backcolor;
extern volatile uint32_t lcdbint_cnt;
extern const uint16_t _imgCms[];
//=======================================================================================================================
void DelayUS(uint32_t us)
{
	while(--us);
}

void LCDPannel_WR_REG(uint8_t reg)
{
	LCD_CS_LOW();
	LCD_DC_LOW();
	
	Write_LBDATAL(reg);

	LCD_CS_HIGH();
}

void LCDPannel_WR_DATA(uint8_t dat)
{
	LCD_CS_LOW();
	LCD_DC_HIGH();
	
	Write_LBDATAL(dat);

	LCD_CS_HIGH();
}

void LCDPannel_Init(void)
{
	LCD_CS_LOW();	
	LCD_RST_LOW();//HAL_GPIO_WritePin(TFT_RST_GPIO_PortPin,GPIO_PIN_RESET);	
	DelayUS(120000*48);//HAL_Delay(120);
	LCD_RST_HIGH();//HAL_GPIO_WritePin(TFT_RST_GPIO_PortPin,GPIO_PIN_SET);
	DelayUS(100000*48);//HAL_Delay(10);	
	 
	//************* Start Initial Sequence **********//		
	LCDPannel_WR_REG(0xCF);  
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_DATA(0xC1); 
	LCDPannel_WR_DATA(0X30); 
	LCDPannel_WR_REG(0xED);  
	LCDPannel_WR_DATA(0x64); 
	LCDPannel_WR_DATA(0x03); 
	LCDPannel_WR_DATA(0X12); 
	LCDPannel_WR_DATA(0X81); 
	LCDPannel_WR_REG(0xE8);  
	LCDPannel_WR_DATA(0x85); 
	LCDPannel_WR_DATA(0x10); 
	LCDPannel_WR_DATA(0x7A); 
	LCDPannel_WR_REG(0xCB);  
	LCDPannel_WR_DATA(0x39); 
	LCDPannel_WR_DATA(0x2C); 
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_DATA(0x34); 
	LCDPannel_WR_DATA(0x02); 
	LCDPannel_WR_REG(0xF7);  
	LCDPannel_WR_DATA(0x20); 
	LCDPannel_WR_REG(0xEA);  
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_REG(0xC0);    //Power control 
	LCDPannel_WR_DATA(0x1B);   //VRH[5:0] 
	LCDPannel_WR_REG(0xC1);    //Power control 
	LCDPannel_WR_DATA(0x01);   //SAP[2:0];BT[3:0] 
	LCDPannel_WR_REG(0xC5);    //VCM control 
	LCDPannel_WR_DATA(0x30); 	 //3F
	LCDPannel_WR_DATA(0x30); 	 //3C
	LCDPannel_WR_REG(0xC7);    //VCM control2 
	LCDPannel_WR_DATA(0XB7); 
	LCDPannel_WR_REG(0x36);    // Memory Access Control 
	LCDPannel_WR_DATA(0x6C);//(0xC9); 
	LCDPannel_WR_REG(0x3A);   
	LCDPannel_WR_DATA(0x55); 
	LCDPannel_WR_REG(0xB1);   
	LCDPannel_WR_DATA(0x00);   
	LCDPannel_WR_DATA(0x1A); 
	LCDPannel_WR_REG(0xB6);    // Display Function Control 
	LCDPannel_WR_DATA(0x0A); 
	LCDPannel_WR_DATA(0xA2);

	LCDPannel_WR_REG(0xF2);    // 3Gamma Function Disable 
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_REG(0x26);    //Gamma curve selected 
	LCDPannel_WR_DATA(0x01); 
	LCDPannel_WR_REG(0xE0);    //Set Gamma 
	LCDPannel_WR_DATA(0x0F); 
	LCDPannel_WR_DATA(0x2A); 
	LCDPannel_WR_DATA(0x28); 
	LCDPannel_WR_DATA(0x08); 
	LCDPannel_WR_DATA(0x0E); 
	LCDPannel_WR_DATA(0x08); 
	LCDPannel_WR_DATA(0x54); 
	LCDPannel_WR_DATA(0XA9); 
	LCDPannel_WR_DATA(0x43); 
	LCDPannel_WR_DATA(0x0A); 
	LCDPannel_WR_DATA(0x0F); 
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_DATA(0x00); 		 
	LCDPannel_WR_REG(0XE1);    //Set Gamma 
	LCDPannel_WR_DATA(0x00); 
	LCDPannel_WR_DATA(0x15); 
	LCDPannel_WR_DATA(0x17); 
	LCDPannel_WR_DATA(0x07); 
	LCDPannel_WR_DATA(0x11); 
	LCDPannel_WR_DATA(0x06); 
	LCDPannel_WR_DATA(0x2B); 
	LCDPannel_WR_DATA(0x56); 
	LCDPannel_WR_DATA(0x3C); 
	LCDPannel_WR_DATA(0x05); 
	LCDPannel_WR_DATA(0x10); 
	LCDPannel_WR_DATA(0x0F); 
	LCDPannel_WR_DATA(0x3F); 
	LCDPannel_WR_DATA(0x3F); 
	LCDPannel_WR_DATA(0x0F); 
	LCDPannel_WR_REG(0x2B); 
	LCDPannel_WR_DATA(0x00);
	LCDPannel_WR_DATA(0x00);
	LCDPannel_WR_DATA(0x01);
	LCDPannel_WR_DATA(0x3f);
	LCDPannel_WR_REG(0x2A); 
	LCDPannel_WR_DATA(0x00);
	LCDPannel_WR_DATA(0x00);
	LCDPannel_WR_DATA(0x00);
	LCDPannel_WR_DATA(0xef);	 
	LCDPannel_WR_REG(0x11); //Exit Sleep
	DelayUS(120000*48);//delay_ms(120);
	LCDPannel_WR_REG(0x29); //display on
	
	BACKLIGHT_ON();
	
	Clear_Display(0x07e0);//(0x001f);//(0xf800);//
}

void Set_Position(uint16_t x1,uint16_t x2,uint16_t y1,uint16_t y2)
{
	uint16_t xoffset1,xoffset2;
	uint16_t yoffset1,yoffset2;
	
	xoffset1 = TFT_X_OFFSET+x1;
	xoffset2 = TFT_X_OFFSET+x2;
	yoffset1 = TFT_Y_OFFSET+y1;
	yoffset2 = TFT_Y_OFFSET+y2;
	
	LCDPannel_WR_REG(0x2A);
	LCDPannel_WR_DATA(xoffset1>>8);
	LCDPannel_WR_DATA(xoffset1&0xff);
	LCDPannel_WR_DATA(xoffset2>>8);
	LCDPannel_WR_DATA(xoffset2&0xff);
	LCDPannel_WR_REG(0x2B);
	LCDPannel_WR_DATA(yoffset1>>8);
	LCDPannel_WR_DATA(yoffset1&0xff);
	LCDPannel_WR_DATA(yoffset2>>8);
	LCDPannel_WR_DATA(yoffset2&0xff);
}


void Set_BackColor(uint16_t color)
{
	backcolor = color;
	
	LCD_CS_LOW();

	LCD_DC_LOW();

	Write_LBDATAL(0x2C);
	
	LCD_DC_HIGH();
	
	LCDB_Start();
	
	lcdbint_cnt = 0;

	LCDB->LBDATA = color;
	
}

void Clear_Display(uint16_t color)
{
	Set_Position(0,LCD_W-1,0,LCD_H-1);
	Set_BackColor(color);
}


void Delayns(uint32_t ns)
{
	while(--ns);
}

void ShowImage(uint8_t imagenum)
{
	uint32_t i=0,j;
	
	Set_Position(60,259,20,219);
	
	LCD_CS_LOW();

	LCD_DC_LOW();

	Write_LBDATAL(0x2C);
	
	LCD_DC_HIGH();

	j = LCD_CMSICON_Pixel;
 
	while(j)			//write picture CMS data to pannel
	{
		LCDB->LBDATA=_imgCms[i];			//_imgCms is the data of picture
		j--;
		i++;
	}	
	
}

