/******************************************************************************
*
*                  COPYRIGHT (C) 2021 CMS Technologies Ltd.                    *
*                                                                              
*
********************************************************************************
* FileName      : qspi_demo.c                                                  *
* Author        :                                                              *
* Version       : 1.0                                                          *
* Date          : 2021.08.13                                                   *
* Description   :                                                              *
* Function List :                                                              *
********************************************************************************/
#include "qspi_demo.h"
#include "stdio.h"

extern void delayMS(uint32_t n);
extern uint8_t rdata[256];
extern uint8_t wdata[256];
extern uint8_t err;
/******************************************************************************

* Function Name: QSPI_FastRead_Init
* @brief  	qspi init demo
* @param  bound
* @return init status
*******************************************************************************/
void QSPI_FastRead_Init(void)
{
	QSPI_InitTypeDef QSPI_InitStructure = {0};
	
	QSPI_InitStructure.QSPIAccMode = QSPI_Mode_Rom;				//access mode is ROM
	QSPI_InitStructure.QSPIReadMode = QSPI_RMode_QuadIO;   //set read mode is four line output io
	QSPI_InitStructure.QSPISSLWidth = QSPI_QSSL_CLK2;		  //set QSSL high level width is 2 clk
	QSPI_InitStructure.QSPIPeriod = QSPI_SCKPeriod_CLK4;  //set QSPI period is 4 clk		
	qspi_Init(&QSPI_InitStructure); //ʼQSPI
	
}

/******************************************************************************

* Function Name: QSPI_QuadRead_Init
* @brief  	qspi quad read init demo
* @param  bound
* @return init status
*******************************************************************************/
void QSPI_QuadRead_Init(void)
{
	QSPI_InitTypeDef QSPI_InitStructure = {0};
	
	QSPI_InitStructure.QSPIAccMode = QSPI_Mode_Rom;				//access mode is ROM
	QSPI_InitStructure.QSPIProtocolType = QSPI_ProtocolType_Quad;  //QUAD SPI
	QSPI_InitStructure.QSPIReadMode = QSPI_RMode_QuadIO;   //set read mode is four line output io
	QSPI_InitStructure.QSPISSLWidth = QSPI_QSSL_CLK1;		  //set QSSL high level width is 1 clk	
	QSPI_InitStructure.QSPIPeriod = QSPI_SCKPeriod_CLK8;  //set QSPI period is 8 clk
	QSPI_InitStructure.QSPIAddrWidth = QSPI_AddrWith_3byte; //3bytes address
	qspi_Init(&QSPI_InitStructure); //ʼQSPI
	
}

void NorFlash_Init(void)
{
	  //=========================================================================================
  // SPI Flash SoftReset
  //=========================================================================================	
	SoftReset();
	delayMS(1);
	printf("INFO: StatusRegister1 = 0x%02x\n", ReadStatus(STATUS_REG1));	
	printf("INFO: StatusRegister2 = 0x%02x\n", ReadStatus(STATUS_REG2));

  //=========================================================================================
  // SPI Flash Write Protect Disable
  //=========================================================================================		
	if(ReadStatus(STATUS_REG1) != 0x00)
		WriteStatus(STATUS_REG1, 0x00);
	
  //=========================================================================================
  // Enter norflash QPI mode
  //=========================================================================================
  if((ReadStatus(STATUS_REG2) & QE_Msk) == 0x00)
  	WriteStatus(STATUS_REG2, QE_Msk);
}

/******************************************************************************************
  * @brief  write data to norflash
  * @param  none
  * @retval none
********************************************************************************************/
void QSPI_WriteNorFlash(void)
{
	uint32_t i;
	
	NorFlash_Init(); 	//initial norflash
	
	if(ReadStatus(STATUS_REG2) & QE_Msk)
  {
    EnableQPI();
		QSPI_Protocol_Set(QSPI_ProtocolType_Quad);  // Quad SPI protocal 
		printf("INFO: Entered QPI mode!!!\n");
	}
	
	//initial wdata[]
	for(i=0; i<256; i++) 
	{
		wdata[i] = i;
  }
		
	//=========================================================================================
  // Block Erase (32KB Block Erase for W25Q128)
  //=========================================================================================
  printf("INFO: Block Erase...\n");
  EraseBlock(FLASH_ADDR - FLASH_BASE);
	
	//=========================================================================================
  // Program
  //=========================================================================================
  printf("INFO: Page Program...\n");
  for(i=0; i<4; i++) {
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0000 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 0]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0011 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 1]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0022 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 2]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0033 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 3]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0044 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 4]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0055 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 5]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0066 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 6]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0077 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 7]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0088 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 8]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0099 + 1 * i, 1, (uint8_t *)&wdata[1 * i + 9]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x00AA + 1 * i, 1, (uint8_t *)&wdata[1 * i + 10]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x00BB + 1 * i, 1, (uint8_t *)&wdata[1 * i + 11]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x00CC + 1 * i, 1, (uint8_t *)&wdata[1 * i + 12]);
  }
  for(i=0; i<4; i++) {
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0100 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 0]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0111 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 1]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0122 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 2]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0133 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 3]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0144 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 4]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0155 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 5]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0166 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 6]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0177 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 7]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0188 + 2 * i, 2, (uint8_t *)&wdata[2 * i + 8]);
  }
  for(i=0; i<4; i++) {
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0200 + 3 * i, 3, (uint8_t *)&wdata[3 * i + 0]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0211 + 3 * i, 3, (uint8_t *)&wdata[3 * i + 1]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0222 + 3 * i, 3, (uint8_t *)&wdata[3 * i + 2]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0233 + 3 * i, 3, (uint8_t *)&wdata[3 * i + 3]);
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0244 + 3 * i, 3, (uint8_t *)&wdata[3 * i + 4]);
  }
  for(i=0; i<4; i++) {
  	ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0300 + 4 * i, 4, (uint8_t *)&wdata[4 * i + 0]);
  }
  ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0400, 128, (uint8_t *)&wdata[0]);
  ProgramPage((FLASH_ADDR - FLASH_BASE) + 0x0480, 128, (uint8_t *)&wdata[128]);
}

/******************************************************************************************
  * @brief  quad io read data from norflash
  * @param  none
  * @retval none
********************************************************************************************/
uint8_t QSPI_NorFlash_QUADRead(void)
{
	uint32_t *ptr;
	uint32_t i;
	
	QSPI_QuadRead_Init();
  printf("INFO: Read data...\n");

  //-----------------------------------------------------------------------------------------
  // Read Data section 1
  //-----------------------------------------------------------------------------------------
  ptr = (uint32_t *)rdata;
  for(i=0; i<52; i++)
  {
      *ptr++ = (*((uint32_t *)(FLASH_ADDR + 0x0000) + i));
  }

#ifdef DATA_PRINT
  // print data section 1
  for(i=0; i<208; i++)
  {
	  if(i % 16 == 0) printf("0x%05X:", (FLASH_ADDR - FLASH_BASE + 0x0000) + i);
      printf(" %02X", rdata[i]);
	  if(i % 16 == 15) printf("\n");
  }

#endif
}

/******************************************************************************************
  * @brief  XIP read data from norflash
  * @param  none
  * @retval none
********************************************************************************************/
uint8_t QSPI_NorFlash_XIPRead(void)
{
	uint32_t *ptr;
	uint32_t i;
	
	QSPI_QuadRead_Init();
	QSPI_XIP_Set(ENABLE);
	
  ptr = (uint32_t *)rdata;
  for(i=0; i<36; i++)
  {
      *ptr++ = (*((uint32_t *)(FLASH_ADDR + 0x0100) + i));
  }

#ifdef DATA_PRINT
  // print data section 2
  for(i=0; i<144; i++)
  {
	  if(i % 16 == 0) printf("0x%05X:", (FLASH_ADDR - FLASH_BASE + 0x0100) + i);
      printf(" %02X", rdata[i]);
	  if(i % 16 == 15) printf("\n");
  }

#endif
}

/******************************************************************************************
  * @brief  disable XIP read data from norflash sector3
  * @param  none
  * @retval none
********************************************************************************************/
uint8_t QSPI_NorFlash_ReadSector3(void)
{
	uint32_t *ptr;
	uint32_t i;
	
	QSPI_QuadRead_Init();
	QSPI_XIP_Set(DISABLE);
	
  ptr = (uint32_t *)rdata;
  for(i=0; i<20; i++)
  {
      *ptr++ = (*((uint32_t *)(FLASH_ADDR + 0x0200) + i));
  }

#ifdef DATA_PRINT
  // print data section 3
  for(i=0; i<80; i++)
  {
	  if(i % 16 == 0) printf("0x%05X:", (FLASH_ADDR - FLASH_BASE + 0x0200) + i);
      printf(" %02X", rdata[i]);
	  if(i % 16 == 15) printf("\n");
  }
	
#endif
	
}


/******************************************************************************************
  * @brief  prefetch mode read data from norflash
  * @param  none
  * @retval none
********************************************************************************************/
uint8_t QSPI_NorFlash_PrefetchRead(void)
{
	uint32_t *ptr;
	uint32_t i;
	
	QSPI_QSSLDelay_Set(QSPI_SSLDelay_None);
	QSPI_Prefetch_Set(ENABLE);
	QSPI_XIP_Set(DISABLE);
  ptr = (uint32_t *)rdata;
  for(i=0; i<32; i++)
  {
      *ptr++ = (*((uint32_t *)(FLASH_ADDR + 0x0400) + i));
  }

#ifdef DATA_PRINT
  // print data section 5-1
  for(i=0; i<128; i++)
  {
	  if(i % 16 == 0) printf("0x%05X:", (FLASH_ADDR - FLASH_BASE + 0x0400) + i);
      printf(" %02X", rdata[i]);
	  if(i % 16 == 15) printf("\n");
  }

#endif
	return 0;
}